==> elgg-1.10.1.zip: elgg-1.10.1/mod/file/languages/ru.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "файлы",
	'file:user' => "Файлы пользователя %s'",
	'file:friends' => "Файлы друзей",
	'file:all' => "Все файлы",
	'file:edit' => "Редактировать файл",
	'file:more' => "Еще файлы",
	'file:list' => "в виде списка",
	'file:group' => "Файлы группы",
	'file:gallery' => "в виде галереи",
	'file:gallery_list' => "В виде галереи или списка",
	'file:num_files' => "Число отображаемых файлов",
	'file:user:gallery'=>'Просмотреть галерею %s',
	'file:upload' => "Загрузить файл",
	'file:replace' => 'Заменить файл (оставьте пустым чтобы не менять файл)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Friends'",

	'file:add' => 'Загрузить файл',

	'file:file' => "Файл",

	'file:list:list' => 'Вид списком',
	'file:list:gallery' => 'Вид галлерея',

	'file:types' => "Типы загружаемых файлов",

	'file:type:' => 'Файлы',
	'file:type:all' => "Все файлы",
	'file:type:video' => "Видео",
	'file:type:document' => "Документы",
	'file:type:audio' => "Аудио",
	'file:type:image' => "Изображения",
	'file:type:general' => "Основные файлы",

	'file:user:type:video' => "Видео %s",
	'file:user:type:document' => "Документы %s",
	'file:user:type:audio' => "Аудио %s",
	'file:user:type:image' => "Изображения %s",
	'file:user:type:general' => "Основные файлы %s",

	'file:friends:type:video' => "Видео Ваших друзей",
	'file:friends:type:document' => "Документы Ваших друзей",
	'file:friends:type:audio' => "Аудио Ваших друзей",
	'file:friends:type:image' => "Изображения Ваших друзей",
	'file:friends:type:general' => "Основные файлы Ваших друзей",

	'file:widget' => "Файлы",
	'file:widget:description' => "Ваши последние файлы",

	'groups:enablefiles' => 'Включить файлы в группе',

	'file:delete:confirm' => "Удалить этот файл?",

	'file:upload_limit' => 'Максимальный допустимый размер файла %s',

	'file:tagcloud' => "Облако тегов",

	'file:display:number' => "Число отображаемых файлов",

	'river:create:object:file' => '%s загрузил(а) файл %s',
	'river:comment:object:file' => '%s комментировал(а) файл %s',

	'item:object:file' => 'Файлы',

	'file:notify:summary' => 'Новый файл: %s',
	'file:notify:subject' => 'Новый файл: %s',
	'file:notify:body' =>
'%s загрузил[а] новый файл: %s

%s

Для просмотра и комментирования перейдите по ссылке:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Ваш файл успешно сохранен.",
	'file:deleted' => "Ваш файл успешно удален.",

	/**
	 * Error messages
	 */

	'file:none' => "---",
	'file:uploadfailed' => "Простите, файл не сохранен.",
	'file:downloadfailed' => "Простите, файл сейчас недоступен.",
	'file:deletefailed' => "Простите, файл не удален.",
	'file:noaccess' => "У Вас нет прав для изменения этого файла.",
	'file:nofile' => "Вам нужно выбрать файл",
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/file/languages/ru.php <==
<?php
return array(

	'item:object:file' => 'Файл',
	'collection:object:file' => 'Файлы',
	'collection:object:file:all' => "Файлы всего сайта",
	'collection:object:file:owner' => "Файлы %s",
	'collection:object:file:friends' => "Файлы друга",
	'collection:object:file:group' => "Сгруппировать файлы",
	'add:object:file' => "Загрузить файл",
	'edit:object:file' => "Редактировать файл",

	'file:more' => "Еще файлы",
	'file:list' => "в виде списка",

	'file:num_files' => "Число отображаемых файлов",
	'file:replace' => 'Заменить файл (оставьте пустым чтобы не менять файл)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Friends'",

	'file:file' => "Файл",

	'file:list:list' => 'Вид списком',
	'file:list:gallery' => 'Вид галлерея',

	'file:types' => "Типы загружаемых файлов",

	'file:type:' => 'Файлы',
	'file:type:all' => "Все файлы",
	'file:type:video' => "Видео",
	'file:type:document' => "Документы",
	'file:type:audio' => "Аудио",
	'file:type:image' => "Изображения",
	'file:type:general' => "Основные файлы",

	'file:user:type:video' => "Видео %s",
	'file:user:type:document' => "Документы %s",
	'file:user:type:audio' => "Аудио %s",
	'file:user:type:image' => "Изображения %s",
	'file:user:type:general' => "Основные файлы %s",

	'file:friends:type:video' => "Видео Ваших друзей",
	'file:friends:type:document' => "Документы Ваших друзей",
	'file:friends:type:audio' => "Аудио Ваших друзей",
	'file:friends:type:image' => "Изображения Ваших друзей",
	'file:friends:type:general' => "Основные файлы Ваших друзей",

	'widgets:filerepo:name' => "File widget",
	'widgets:filerepo:description' => "Showcase your latest files",

	'groups:tool:file' => 'Разрешить группировку файлов',

	'river:object:file:create' => '%sзагрузил файл %s',
	'river:object:file:comment' => '%sпрокомментировал файл %s',

	'file:notify:summary' => 'Новый файл: %s',
	'file:notify:subject' => 'Новый файл: %s',
	'file:notify:body' => '%s uploaded a new file: %s

%s

View and comment on the file:
%s',

	/**
	 * Status messages
	 */

	'file:saved' => "The file was successfully saved.",
	'entity:delete:object:file:success' => "The file was successfully deleted.",

	/**
	 * Error messages
	 */

	'file:none' => "---",
	'file:uploadfailed' => "Простите, файл не сохранен.",
	'file:noaccess' => "У Вас нет прав для изменения этого файла.",
	'file:cannotload' => "Ошибка загрузки файла",
);
